replace all occurrences of occured by occurred

Do it in all comments and errors messages
diff --git a/include/libimobiledevice/house_arrest.h b/include/libimobiledevice/house_arrest.h
index 31b6401..5a42838 100644
--- a/include/libimobiledevice/house_arrest.h
+++ b/include/libimobiledevice/house_arrest.h
@@ -109,7 +109,7 @@
  *     HOUSE_ARREST_E_INVALID_ARG if client or dict is invalid,
  *     HOUSE_ARREST_E_PLIST_ERROR if dict is not a plist of type PLIST_DICT,
  *     HOUSE_ARREST_E_INVALID_MODE if the client is not in the correct mode,
- *     or HOUSE_ARREST_E_CONN_FAILED if a connection error occured.
+ *     or HOUSE_ARREST_E_CONN_FAILED if a connection error occurred.
  */
 house_arrest_error_t house_arrest_send_request(house_arrest_client_t client, plist_t dict);
 
@@ -130,7 +130,7 @@
  * @return HOUSE_ARREST_E_SUCCESS if the command was successfully sent,
  *     HOUSE_ARREST_E_INVALID_ARG if client, command, or appid is invalid,
  *     HOUSE_ARREST_E_INVALID_MODE if the client is not in the correct mode,
- *     or HOUSE_ARREST_E_CONN_FAILED if a connection error occured.
+ *     or HOUSE_ARREST_E_CONN_FAILED if a connection error occurred.
  */
 house_arrest_error_t house_arrest_send_command(house_arrest_client_t client, const char *command, const char *appid);
 
@@ -146,7 +146,7 @@
  * @return HOUSE_ARREST_E_SUCCESS if a result plist was retrieved,
  *     HOUSE_ARREST_E_INVALID_ARG if client is invalid,
  *     HOUSE_ARREST_E_INVALID_MODE if the client is not in the correct mode,
- *     or HOUSE_ARREST_E_CONN_FAILED if a connection error occured.
+ *     or HOUSE_ARREST_E_CONN_FAILED if a connection error occurred.
  */
 house_arrest_error_t house_arrest_get_result(house_arrest_client_t client, plist_t *dict);
 
diff --git a/include/libimobiledevice/installation_proxy.h b/include/libimobiledevice/installation_proxy.h
index bc23f9d..1ff82dc 100644
--- a/include/libimobiledevice/installation_proxy.h
+++ b/include/libimobiledevice/installation_proxy.h
@@ -124,7 +124,7 @@
  *        instproxy_client_t upon successful return.
  *
  * @return INSTPROXY_E_SUCCESS on success, or an INSTPROXY_E_* error value
- *         when an error occured.
+ *         when an error occurred.
  */
 instproxy_error_t instproxy_client_new(idevice_t device, lockdownd_service_descriptor_t service, instproxy_client_t *client);
 
@@ -168,7 +168,7 @@
  *        of PLIST_DICT holding information about the applications found.
  *
  * @return INSTPROXY_E_SUCCESS on success or an INSTPROXY_E_* error value if
- *         an error occured.
+ *         an error occurred.
  */
 instproxy_error_t instproxy_browse(instproxy_client_t client, plist_t client_options, plist_t *result);
 
@@ -187,7 +187,7 @@
  * @param user_data Callback data passed to status_cb.
  *
  * @return INSTPROXY_E_SUCCESS on success or an INSTPROXY_E_* error value if
- *         an error occured.
+ *         an error occurred.
  */
 instproxy_error_t instproxy_browse_with_callback(instproxy_client_t client, plist_t client_options, instproxy_status_cb_t status_cb, void *user_data);
 
@@ -203,7 +203,7 @@
  *        holding requested information about the application or NULL on errors.
  *
  * @return INSTPROXY_E_SUCCESS on success or an INSTPROXY_E_* error value if
- *         an error occured.
+ *         an error occurred.
  */
 instproxy_error_t instproxy_lookup(instproxy_client_t client, const char** appids, plist_t client_options, plist_t *result);
 
@@ -224,7 +224,7 @@
  * @param user_data Callback data passed to status_cb.
  *
  * @return INSTPROXY_E_SUCCESS on success or an INSTPROXY_E_* error value if
- *         an error occured.
+ *         an error occurred.
  *
  * @note If a callback function is given (async mode), this function returns
  *       INSTPROXY_E_SUCCESS immediately if the status updater thread has been
@@ -252,7 +252,7 @@
  * @param user_data Callback data passed to status_cb.
  *
  * @return INSTPROXY_E_SUCCESS on success or an INSTPROXY_E_* error value if
- *         an error occured.
+ *         an error occurred.
  *
  * @note If a callback function is given (async mode), this function returns
  *       INSTPROXY_E_SUCCESS immediately if the status updater thread has been
@@ -273,7 +273,7 @@
  * @param user_data Callback data passed to status_cb.
  *
  * @return INSTPROXY_E_SUCCESS on success or an INSTPROXY_E_* error value if
- *     an error occured.
+ *     an error occurred.
  *
  * @note If a callback function is given (async mode), this function returns
  *       INSTPROXY_E_SUCCESS immediately if the status updater thread has been
@@ -294,7 +294,7 @@
  *        holding information about the archived applications found.
  *
  * @return INSTPROXY_E_SUCCESS on success or an INSTPROXY_E_* error value if
- *         an error occured.
+ *         an error occurred.
  */
 instproxy_error_t instproxy_lookup_archives(instproxy_client_t client, plist_t client_options, plist_t *result);
 
@@ -315,7 +315,7 @@
  * @param user_data Callback data passed to status_cb.
  *
  * @return INSTPROXY_E_SUCCESS on success or an INSTPROXY_E_* error value if
- *     an error occured.
+ *     an error occurred.
  *
  * @note If a callback function is given (async mode), this function returns
  *       INSTPROXY_E_SUCCESS immediately if the status updater thread has been
@@ -339,7 +339,7 @@
  * @param user_data Callback data passed to status_cb.
  *
  * @return INSTPROXY_E_SUCCESS on success or an INSTPROXY_E_* error value if
- *     an error occured.
+ *     an error occurred.
  *
  * @note If a callback function is given (async mode), this function returns
  *       INSTPROXY_E_SUCCESS immediately if the status updater thread has been
@@ -362,7 +362,7 @@
  * @param user_data Callback data passed to status_cb.
  *
  * @return INSTPROXY_E_SUCCESS on success or an INSTPROXY_E_* error value if
- *         an error occured.
+ *         an error occurred.
  *
  * @note If a callback function is given (async mode), this function returns
  *       INSTPROXY_E_SUCCESS immediately if the status updater thread has been
@@ -383,7 +383,7 @@
  *        holding information if the capabilities matched or NULL on errors.
  *
  * @return INSTPROXY_E_SUCCESS on success or an INSTPROXY_E_* error value if
- *         an error occured.
+ *         an error occurred.
  */
 instproxy_error_t instproxy_check_capabilities_match(instproxy_client_t client, const char** capabilities, plist_t client_options, plist_t *result);
 
@@ -493,7 +493,7 @@
  *
  * @return INSTPROXY_E_SUCCESS on success, INSTPROXY_E_OP_FAILED if
  *         the path could not be determined or an INSTPROXY_E_* error
- *         value if an error occured.
+ *         value if an error occurred.
  */
 instproxy_error_t instproxy_client_get_path_for_bundle_identifier(instproxy_client_t client, const char* bundle_id, char** path);
 
diff --git a/include/libimobiledevice/libimobiledevice.h b/include/libimobiledevice/libimobiledevice.h
index 729bc89..8f8589d 100644
--- a/include/libimobiledevice/libimobiledevice.h
+++ b/include/libimobiledevice/libimobiledevice.h
@@ -60,7 +60,7 @@
 };
 
 /* event data structure */
-/** Provides information about the occured event. */
+/** Provides information about the occurred event. */
 typedef struct {
 	enum idevice_event_type event; /**< The event type. */
 	const char *udid; /**< The device unique id. */
@@ -88,7 +88,7 @@
  * @param user_data Application-specific data passed as parameter
  *   to the registered callback function.
  *
- * @return IDEVICE_E_SUCCESS on success or an error value when an error occured.
+ * @return IDEVICE_E_SUCCESS on success or an error value when an error occurred.
  */
 idevice_error_t idevice_event_subscribe(idevice_event_cb_t callback, void *user_data);
 
@@ -96,7 +96,7 @@
  * Release the event callback function that has been registered with
  *  idevice_event_subscribe().
  *
- * @return IDEVICE_E_SUCCESS on success or an error value when an error occured.
+ * @return IDEVICE_E_SUCCESS on success or an error value when an error occurred.
  */
 idevice_error_t idevice_event_unsubscribe(void);
 
@@ -109,7 +109,7 @@
  *   This list is terminated by a NULL pointer.
  * @param count Number of devices found.
  *
- * @return IDEVICE_E_SUCCESS on success or an error value when an error occured.
+ * @return IDEVICE_E_SUCCESS on success or an error value when an error occurred.
  */
 idevice_error_t idevice_get_device_list(char ***devices, int *count);
 
diff --git a/include/libimobiledevice/mobilebackup2.h b/include/libimobiledevice/mobilebackup2.h
index 1f20d40..0c42334 100644
--- a/include/libimobiledevice/mobilebackup2.h
+++ b/include/libimobiledevice/mobilebackup2.h
@@ -146,7 +146,7 @@
  * Receive binary from the device.
  *
  * @note This function returns MOBILEBACKUP2_E_SUCCESS even if no data
- *     has been received (unless a communication error occured).
+ *     has been received (unless a communication error occurred).
  *     The fourth parameter is required and must be checked to know how
  *     many bytes were actually received.
  *
diff --git a/include/libimobiledevice/property_list_service.h b/include/libimobiledevice/property_list_service.h
index aca966d..031d6f8 100644
--- a/include/libimobiledevice/property_list_service.h
+++ b/include/libimobiledevice/property_list_service.h
@@ -68,7 +68,7 @@
  *
  * @return PROPERTY_LIST_SERVICE_E_SUCCESS on success,
  *     PROPERTY_LIST_SERVICE_E_INVALID_ARG when client is invalid, or a
- *     PROPERTY_LIST_SERVICE_E_UNKNOWN_ERROR when another error occured.
+ *     PROPERTY_LIST_SERVICE_E_UNKNOWN_ERROR when another error occurred.
  */
 property_list_service_error_t property_list_service_client_free(property_list_service_client_t client);
 
diff --git a/include/libimobiledevice/screenshotr.h b/include/libimobiledevice/screenshotr.h
index 0d44255..c12646b 100644
--- a/include/libimobiledevice/screenshotr.h
+++ b/include/libimobiledevice/screenshotr.h
@@ -104,7 +104,7 @@
  *
  * @return SCREENSHOTR_E_SUCCESS on success, SCREENSHOTR_E_INVALID_ARG if
  *     one or more parameters are invalid, or another error code if an
- *     error occured.
+ *     error occurred.
  */
 screenshotr_error_t screenshotr_take_screenshot(screenshotr_client_t client, char **imgdata, uint64_t *imgsize);
 
diff --git a/include/libimobiledevice/service.h b/include/libimobiledevice/service.h
index facf03b..84c5092 100644
--- a/include/libimobiledevice/service.h
+++ b/include/libimobiledevice/service.h
@@ -87,7 +87,7 @@
  *
  * @return SERVICE_E_SUCCESS on success,
  *     SERVICE_E_INVALID_ARG when client is invalid, or a
- *     SERVICE_E_UNKNOWN_ERROR when another error occured.
+ *     SERVICE_E_UNKNOWN_ERROR when another error occurred.
  */
 service_error_t service_client_free(service_client_t client);
 
diff --git a/src/diagnostics_relay.c b/src/diagnostics_relay.c
index 79e041e..0834700 100644
--- a/src/diagnostics_relay.c
+++ b/src/diagnostics_relay.c
@@ -36,7 +36,7 @@
  *
  * @return RESULT_SUCCESS when the result is 'Success',
  *         RESULT_FAILURE when the result is 'Failure',
- *         or a negative value if an error occured during evaluation.
+ *         or a negative value if an error occurred during evaluation.
  */
 static int diagnostics_relay_check_result(plist_t dict)
 {
diff --git a/src/installation_proxy.c b/src/installation_proxy.c
index 24044aa..7c2d336 100644
--- a/src/installation_proxy.c
+++ b/src/installation_proxy.c
@@ -286,7 +286,7 @@
  * @param package_path The installation package path or NULL if not required.
  *
  * @return INSTPROXY_E_SUCCESS on success or an INSTPROXY_E_* error value if
- *     an error occured.
+ *     an error occurred.
  */
 static instproxy_error_t instproxy_send_command(instproxy_client_t client, plist_t command)
 {
@@ -460,7 +460,7 @@
  *
  * @return INSTPROXY_E_SUCCESS when the thread was created (async mode), or
  *         when the command completed successfully (sync).
- *         An INSTPROXY_E_* error value is returned if an error occured.
+ *         An INSTPROXY_E_* error value is returned if an error occurred.
  */
 static instproxy_error_t instproxy_receive_status_loop_with_callback(instproxy_client_t client, plist_t command, instproxy_command_type_t async, instproxy_status_cb_t status_cb, void *user_data)
 {
@@ -505,7 +505,7 @@
  * @param user_data Callback data passed to status_cb.
  *
  * @return INSTPROXY_E_SUCCESS on success or an INSTPROXY_E_* error value if
- *     an error occured.
+ *     an error occurred.
  */
 static instproxy_error_t instproxy_perform_command(instproxy_client_t client, plist_t command, instproxy_command_type_t async, instproxy_status_cb_t status_cb, void *user_data)
 {
diff --git a/src/lockdown.c b/src/lockdown.c
index 1a162ed..23f2782 100644
--- a/src/lockdown.c
+++ b/src/lockdown.c
@@ -219,7 +219,7 @@
 					ret = lockdownd_strtoerr(err_value);
 					free(err_value);
 				} else {
-					debug_info("ERROR: unknown error occured");
+					debug_info("ERROR: unknown error occurred");
 				}
 			}
 			return ret;
diff --git a/src/misagent.c b/src/misagent.c
index 095edba..91b8acb 100644
--- a/src/misagent.c
+++ b/src/misagent.c
@@ -57,7 +57,7 @@
 
 /**
  * Checks the response from misagent to determine if the operation
- * was successful or an error occured. Internally used only.
+ * was successful or an error occurred. Internally used only.
  *
  * @param response a PLIST_DICT received from device's misagent
  * @param status_code pointer to an int that will be set to the status code
diff --git a/src/restore.c b/src/restore.c
index 4b578c2..6571a2f 100644
--- a/src/restore.c
+++ b/src/restore.c
@@ -41,7 +41,7 @@
  *
  * @return RESULT_SUCCESS when the result is 'Success',
  *         RESULT_FAILURE when the result is 'Failure',
- *         or a negative value if an error occured during evaluation.
+ *         or a negative value if an error occurred during evaluation.
  */
 static int restored_check_result(plist_t dict)
 {
diff --git a/tools/idevicebackup.c b/tools/idevicebackup.c
index cd69bcc..de08295 100644
--- a/tools/idevicebackup.c
+++ b/tools/idevicebackup.c
@@ -995,7 +995,7 @@
 				} else if (err == MOBILEBACKUP_E_REPLY_NOT_OK) {
 					printf("ERROR: Could not start backup process: device refused to start the backup process.\n");
 				} else {
-					printf("ERROR: Could not start backup process: unspecified error occured\n");
+					printf("ERROR: Could not start backup process: unspecified error occurred\n");
 				}
 				break;
 			}
@@ -1342,7 +1342,7 @@
 				} else if (err == MOBILEBACKUP_E_REPLY_NOT_OK) {
 					printf("ERROR: Could not start restore process: device refused to start the restore process.\n");
 				} else {
-					printf("ERROR: Could not start restore process: unspecified error occured (%d)\n", err);
+					printf("ERROR: Could not start restore process: unspecified error occurred (%d)\n", err);
 				}
 				plist_free(backup_data);
 				break;
diff --git a/tools/idevicebackup2.c b/tools/idevicebackup2.c
index 0aae36e..58fda8d 100644
--- a/tools/idevicebackup2.c
+++ b/tools/idevicebackup2.c
@@ -1954,7 +1954,7 @@
 				} else if (err == MOBILEBACKUP2_E_REPLY_NOT_OK) {
 					printf("ERROR: Could not start backup process: device refused to start the backup process.\n");
 				} else {
-					printf("ERROR: Could not start backup process: unspecified error occured\n");
+					printf("ERROR: Could not start backup process: unspecified error occurred\n");
 				}
 				cmd = CMD_LEAVE;
 			}
@@ -2012,7 +2012,7 @@
 				} else if (err == MOBILEBACKUP2_E_REPLY_NOT_OK) {
 					printf("ERROR: Could not start restore process: device refused to start the restore process.\n");
 				} else {
-					printf("ERROR: Could not start restore process: unspecified error occured\n");
+					printf("ERROR: Could not start restore process: unspecified error occurred\n");
 				}
 				cmd = CMD_LEAVE;
 			}
diff --git a/src/notification_proxy.c b/src/notification_proxy.c
index cd8e64c..eea01ca 100644
--- a/src/notification_proxy.c
+++ b/src/notification_proxy.c
@@ -247,7 +247,7 @@
  *  with the notification that has been received.
  *
  * @return 0 if a notification has been received or nothing has been received,
  *         or a negative value if an error occured.
  *
  * @note You probably want to check out np_set_notify_callback
  * @see np_set_notify_callback
@@ -267,7 +267,7 @@
 		debug_info("NotificationProxy: no notification received!");
 		res = 0;
 	} else if (perr != PROPERTY_LIST_SERVICE_E_SUCCESS) {
-		debug_info("NotificationProxy: error %d occured!", perr);
+		debug_info("NotificationProxy: error %d occurred!", perr);
 		res = perr;
 	}
 	if (dict) {
@@ -247,7 +247,7 @@
  *
  * @return 0 if a notification has been received or nothing has been received,
- *         or a negative value if an error occured.
+ *         or a negative value if an error occurred.
  *
  * @note You probably want to check out np_set_notify_callback